@@ -46,7 +46,7 @@ def get(name: str) -> Connection:
     return connections.get(name)
 
 
-def session(self, name: str) -> AsyncSession:
+def session(name: str) -> AsyncSession:
     """Create a new :class:`sqlalchemy.ext.asyncio.AsyncSession`
     instance for the named connection `name`.
     """
